/*
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Esmart/Esmart_Trans_X11.h>
#include <evas/rb_evas.h>
#include <evas/rb_evas_object.h>
#include <ecore/rb_window.h>

#include "../rb_esmart.h"

static VALUE cWindow;

static VALUE c_init (VALUE self, VALUE evas)
{
	CHECK_CLASS (evas, cEvas);
	GET_OBJ (evas, RbEvas, e);
	GET_OBJ (self, RbEvasObject, trans);

	trans->real = esmart_trans_x11_new (e->real);

	rb_call_super (1, &evas);

	return self;
}

static VALUE c_type_get (VALUE self)
{
	GET_OBJ (self, RbEvasObject, e);

	return INT2FIX (esmart_trans_x11_type_get (e->real));
}

static VALUE c_type_set (VALUE self, VALUE val)
{
	GET_OBJ (self, RbEvasObject, e);

	Check_Type (val, T_FIXNUM);

	esmart_trans_x11_type_set (e->real, FIX2INT (val));

	return Qnil;
}

static VALUE c_window_set (VALUE self, VALUE window)
{
	GET_OBJ (self, RbEvasObject, e);

	CHECK_CLASS (window, cWindow);
	GET_OBJ (window, RbWindow, w);

	esmart_trans_x11_window_set (e->real, w->real);

	return Qnil;
}

static VALUE c_freshen (VALUE self, VALUE x, VALUE y, VALUE w, VALUE h)
{
	GET_OBJ (self, RbEvasObject, e);

	Check_Type (x, T_FIXNUM);
	Check_Type (y, T_FIXNUM);
	Check_Type (w, T_FIXNUM);
	Check_Type (h, T_FIXNUM);

	esmart_trans_x11_freshen (e->real, FIX2INT (x), FIX2INT (y),
	                          FIX2INT (w), FIX2INT (h));

	return Qnil;
}

void Init_esmart_trans_x11 (void)
{
	VALUE m, c;

	rb_require ("esmart");
	rb_require ("ecore_x");

	m = rb_const_get (rb_cModule, rb_intern ("Ecore"));
	m = rb_const_get (m, rb_intern ("X"));
	cWindow = rb_const_get (m, rb_intern ("Window"));

	c = rb_define_class_under (mEsmart, "TransX11", cEvasObject);

	rb_define_method (c, "initialize", c_init, 1);
	rb_define_method (c, "type", c_type_get, 0);
	rb_define_method (c, "type=", c_type_set, 1);
	rb_define_method (c, "window=", c_window_set, 1);
	rb_define_method (c, "freshen", c_freshen, 4);

	rb_define_const (c, "BACKGROUND",
	                 INT2FIX (Esmart_Trans_X11_Type_Background));
	rb_define_const (c, "SCREENGRAB",
	                 INT2FIX (Esmart_Trans_X11_Type_Screengrab));
}
